@@ -4,6 +4,7 @@ require 'spec_helper'
 
 require 'puppet/indirector/node/puppetdb'
 require 'puppet/util/puppetdb/command_names'
+require 'json'
 
 describe Puppet::Node::Puppetdb do
 
@@ -26,23 +27,20 @@ describe Puppet::Node::Puppetdb do
       Puppet::Network::HttpPool.expects(:http_instance).returns http
     end
 
-    it "should POST a '#{CommandDeactivateNode}' command as a URL-encoded PSON string" do
+    it "should POST a '#{CommandDeactivateNode}' command as a URL-encoded JSON string" do
       response.stubs(:body).returns '{"uuid": "a UUID"}'
 
       payload = {
         :command => CommandDeactivateNode,
-        :version => 1,
-        :payload => node.to_pson,
-      }.to_pson
+        :version => 2,
+        :payload => node,
+      }.to_json
 
       http.expects(:post).with do |uri,body,headers|
-        body =~ /payload=(.+)/
-        @sent_payload = $1
+        expect(body).to eq(payload)
       end.returns response
 
       destroy
-
-      CGI.unescape(@sent_payload).should == payload
     end
 
     it "should log a deprecation warning if one is returned from PuppetDB" do
