@@ -5,9 +5,9 @@
 
 (ns com.puppetlabs.puppetdb.query.paging
   (:import  [com.fasterxml.jackson.core JsonParseException])
-  (:require [cheshire.core :as json]
+  (:require [com.puppetlabs.cheshire :as json]
             [clojure.string :as string])
-  (:use     [com.puppetlabs.utils :only [keyset seq-contains? parse-int order-by-expr?]]
+  (:use     [puppetlabs.kitchensink.core :only [keyset seq-contains? parse-int order-by-expr?]]
             [com.puppetlabs.jdbc :only [underscores->dashes]]
             [com.puppetlabs.http :only [parse-boolean-query-param]]
             [clojure.walk :only (keywordize-keys)]))
@@ -171,7 +171,7 @@
   and return an updated map with the correct integer value.
   Throws an exception if the provided limit is not a positive non-zero integer."
   [paging-options]
-  (update-in paging-options [:limit] #(if (nil? %) nil (validate-limit %))))
+  (update-in paging-options [:limit] #(when-not (nil? %) (validate-limit %))))
 
 (defn validate-offset
   "Validates that the offset string is a non-negative integer. Returns the integer
@@ -190,7 +190,7 @@
   and return an updated map with the correct integer value.
   Throws an exception if the provided offset is not a non-negative integer."
   [paging-options]
-  (update-in paging-options [:offset] #(if (nil? %) nil (validate-offset %))))
+  (update-in paging-options [:offset] #(when-not (nil? %) (validate-offset %))))
 
 (defn validate-order-by!
   "Given a list of keywords representing legal fields for ordering a query, and a map of
